Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(257)

Unified Diff: third_party/WebKit/Source/core/dom/Element.h

Issue 2149893003: Rename Node::inShadowIncludingDocument() to Node::isConnected() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: addressed Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/dom/Document.cpp ('k') | third_party/WebKit/Source/core/dom/Element.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/dom/Element.h
diff --git a/third_party/WebKit/Source/core/dom/Element.h b/third_party/WebKit/Source/core/dom/Element.h
index 6d2740742fb5841243230ecab0ae4d38508cb442..c2fb4fca126c4ad8cbab2c82838947f445b7c8dd 100644
--- a/third_party/WebKit/Source/core/dom/Element.h
+++ b/third_party/WebKit/Source/core/dom/Element.h
@@ -563,7 +563,7 @@ public:
void updateFromCompositorMutation(const CompositorMutation&);
// Helpers for V8DOMActivityLogger::logEvent. They call logEvent only if
// the element is inShadowIncludingDocument() and the context is an isolated world.
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1);
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1, const QualifiedName& attr2);
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1, const QualifiedName& attr2, const QualifiedName& attr3);
@@ -869,9 +869,9 @@ inline Node::InsertionNotificationRequest Node::insertedInto(ContainerNode* inse
{
DCHECK(!childNeedsStyleInvalidation());
DCHECK(!needsStyleInvalidation());
- DCHECK(insertionPoint->inShadowIncludingDocument() || insertionPoint->isInShadowTree() || isContainerNode());
- if (insertionPoint->inShadowIncludingDocument()) {
- setFlag(InDocumentFlag);
+ DCHECK(insertionPoint->isConnected() || insertionPoint->isInShadowTree() || isContainerNode());
+ if (insertionPoint->isConnected()) {
+ setFlag(IsConnectedFlag);
insertionPoint->document().incrementNodeCount();
}
if (parentOrShadowHostNode()->isInShadowTree())
@@ -883,9 +883,9 @@ inline Node::InsertionNotificationRequest Node::insertedInto(ContainerNode* inse
inline void Node::removedFrom(ContainerNode* insertionPoint)
{
- DCHECK(insertionPoint->inShadowIncludingDocument() || isContainerNode() || isInShadowTree());
- if (insertionPoint->inShadowIncludingDocument()) {
- clearFlag(InDocumentFlag);
+ DCHECK(insertionPoint->isConnected() || isContainerNode() || isInShadowTree());
+ if (insertionPoint->isConnected()) {
+ clearFlag(IsConnectedFlag);
insertionPoint->document().decrementNodeCount();
}
if (isInShadowTree() && !containingTreeScope().rootNode().isShadowRoot())
@@ -563,7 +563,7 @@ public:
void updateFromCompositorMutation(const CompositorMutation&);
// Helpers for V8DOMActivityLogger::logEvent. They call logEvent only if
- // the element is inShadowIncludingDocument() and the context is an isolated world.
+ // the element is isConnected() and the context is an isolated world.
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1);
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1, const QualifiedName& attr2);
« no previous file with comments | « third_party/WebKit/Source/core/dom/Document.cpp ('k') | third_party/WebKit/Source/core/dom/Element.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698